%global momorel 4

Name: boost
Summary: The Boost C++ Libraries
Version: 1.30.2
Release: %{momorel}m
License: see "lib_guide.htm#License"
URL: http://www.boost.org/
Group: System Environment/Libraries
Source: http://download.sourceforge.net/boost/boost-%{version}.tar.bz2
NoSource: 0
Patch0: boost-1.30.0-mkdir.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-root
BuildRequires: boost-jam >= 3.1.3, libstdc++-devel, python 

%description
The Boost web site provides free peer-reviewed portable C++ source libraries.
The emphasis is on libraries which work well with the C++ Standard Library.
One goal is to establish "existing practice" and provide reference
implementations so that the Boost libraries are suitable for eventual
standardization. Some of the libraries have already been proposed for inclusion
in the C++ Standards Committee's upcoming C++ Standard Library Technical Report.

# according to ldd (and automatically generated RPM dependencies)
# it doesn't strictly require python, but IMHO it's cleaner to split it this way
%package python
Summary: Boost.Python library
Group: System Environment/Libraries
Requires: boost python

%description python
Use the Boost Python Library to quickly and easily export a C++ library to
Python such that the Python interface is very similar to the C++ interface.
It is designed to be minimally intrusive on your C++ design. In most cases,
you should not have to alter your C++ classes in any way in order to use
them with Boost.Python. The system should simply ``reflect'' your C++ classes
and functions into Python.

%package devel
Summary: Boost C++ development libraries and headers
Group: Development/Libraries
Requires: boost

%description devel
Headers and static libraries for the Boost C++ libraries

%package python-devel
Summary: Boost.Python development headers
Group: Development/Libraries
Requires: boost-devel 

%description python-devel
Headers for the Boost.Python library

%package doc
Summary: Boost C++ Library documentation
Group: Documentation

%description doc
Documentation for the Boost C++ Library

%prep
%setup -q -n %{name}-%{version}
%patch0 -p0 -b .mkdir~

%build
PYTHON_VERSION=`python -V 2>&1 | sed 's,.* \([0-9]\.[0-9]\)\(\.[0-9]\)\?.*,\1,'`
cflags=$(echo %{optflags} | sed 's/\([^[:space:]][^[:space:]]*\)/<cflags>\1/g')
bjam -d2 -sBUILD="release <optimization> $cflags" -sPYTHON_ROOT=/usr -sPYTHON_VERSION=$PYTHON_VERSION

%install
rm -f master.list python.list devel.list python-devel.list doc.list

# include files
mkdir -p %{buildroot}%{_includedir}
find boost -type d -exec mkdir -p %{buildroot}%{_includedir}/{} \;
for i in `find boost -type f`; do
	install -m 644 $i %{buildroot}%{_includedir}/$i
	if echo $i | grep -q python; then
		echo %{_includedir}/$i >> python-devel.list
	else
		echo %{_includedir}/$i >> devel.list
	fi
done

# static libraries
mkdir -p %{buildroot}%{_libdir}
for i in `find libs -type f -name '*.a' | grep gcc`; do
	name=`basename $i`
	install -m 644 $i %{buildroot}%{_libdir}/$name
	if echo $i | grep -q python; then
		echo %{_libdir}/$name >> python-devel.list
	else
		echo %{_libdir}/$name >> devel.list
	fi
done

# dynamic libraries
for i in `find libs -type f -name '*.so.%{version}' | grep gcc`; do
	name=`basename $i`
	install -m 755 $i %{buildroot}%{_libdir}/$name
	#ldconfig fails to generate the symlinks for boost libs :-(
	LINK=`echo $name | sed 's,\.so\..*,.so,'`
	(cd %{buildroot}%{_libdir} && ln -s $name $LINK)
	if echo $i | grep -q python; then
		echo %{_libdir}/$name >> python.list
		echo %{_libdir}/$LINK >> python.list
	else
		echo %{_libdir}/$name >> master.list
		echo %{_libdir}/$LINK >> master.list
	fi
done

# documentation
mkdir -p %{buildroot}%{_docdir}/boost-%{version}
install -m 644 README %{buildroot}%{_docdir}/boost-%{version}
# as the documentation doesn't completely reside in a directory of its own, we
# need to find out ourselves... this looks for HTML files and then collects
# everything linked from those.
# this is certainly quite unoptimized wrt mkdir calls, but does it really matter?
for i in `find -type f -name '*.htm*'`; do
	# bjam docu is included in the boost-jam RPM
	if test "`echo $i | sed 's,jam_src,,'`" = "$i"; then
		mkdir -p %{buildroot}%{_docdir}/boost-%{version}/`dirname $i`
		for LINKED in `perl - $i %{buildroot}%{_docdir}/boost-%{version}/$i <<'EOT'
			sub rewrite_link
			{
				my $link = shift;
				# rewrite links from boost/* to %{_includedir}/boost/* and
				# ignore external links as well as document-internal ones.
				# HTML files are also ignored as they get installed anyway.
				if (!($link =~ s,^(?:../)*boost/,%{_includedir}/boost/,) && !($link =~ m,(?:^[^/]+:|^\#|\.html?(?:$|\#)),))
				{
					(my $file = $link) =~ s/\#.*//;
					print "$file\n";
				}
				$link;
			}
			open IN, @ARGV[0];
			open OUT, ">@ARGV[1]";
            my $in_link;
			while (<IN>)
			{
                $in_link and s/^\s*"([^"> ]*)"/'"' . rewrite_link($1) . '"'/e;
				s/(href|src)="([^"> ]*)"/"$1=\"" . rewrite_link($2) . '"'/eig;
				print OUT;
                $in_link = /href|src=\s*$/;
			}
EOT`; do
			TARGET=`dirname $i`/$LINKED
			# ignore non-existant linked files
			if test -f $TARGET; then
				mkdir -p %{buildroot}%{_docdir}/boost-%{version}/`dirname $TARGET`
				install -m 644 $TARGET %{buildroot}%{_docdir}/boost-%{version}/$TARGET
			fi
		done
	fi
done

%clean
rm -rf %{buildroot}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%post python -p /sbin/ldconfig

%postun python -p /sbin/ldconfig

%files -f master.list
%defattr(-, root, root)

%files python -f python.list
%defattr(-, root, root)

%files devel -f devel.list
%defattr(-, root, root)

%files python-devel -f python-devel.list
%defattr(-, root, root)

%files doc
%defattr(-, root, root)
%doc %{_docdir}/boost-%{version}


%changelog
* Fri May 14 2004 Masahiro Takahata <takahata@momonga-linux.org>
- (1.30.2-4m)
- change URI

* Sun Dec  7 2003 Ryu SASAOKA <ryu@momonga-linux.org>
- (1.30.2-3m)
- adapt the License: preamble for the Momonga Linux license
  expression unification policy (draft)

* Wed Oct 22 2003 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.30.2-2m)
- kill %%define version
- kill %%define release

* Mon Oct 20 2003 Hideo TASHIRO <tashiron@jasmiso.org>
- (1.30.2-1m)
- update to 1.30.2
- change License from "Freeware" to "Distributable"

* Tue Jun 10 2003 KOMATSU Shinichiro <koma2@momonga-linux.org>
- (1.30.0-1m)
- initial version for momonga (imported from rawhide)

* Tue May  6 2003 Tim Powers <timp@redhat.com> 1.30.0-3
- add deffattr's so we don't have unknown users owning files
